============
Introduction
============


Espresso is a community-driven project to assemble a suite of geoscience forward problems, and associated datasets. It is primarily intended to support research into --- and teaching about --- inversion, inference and optimisation algorithms. It provides a curated selection of exemplar problems, each accessed through a standardised interface, with all domain-specific choices (e.g. data selection & processing; model parameterisation; solver configuration) pre-set by domain experts. This allows researchers to quickly and easily test new optimisation tools across a variety of problems, without the need to first acquire significant domain expertise.

